

<?php

use App\Http\Controllers\Admin\MunicipioController;
use App\Http\Controllers\Admin\Relatorios\EscolaMunicipioController;
use App\Http\Controllers\Admin\SobreController;
use Illuminate\Support\Facades\Route;
use Illuminate\Http\Request;

Route::post('/tokens/create', function (Request $request) {
    $token = $request->user()->createToken($request->token_name);

    return ['token' => $token->plainTextToken];
});

route::get('/', ['as' => 'site.dashboard', 'uses' => 'Site\HomeController@index']);

Route::prefix('/site')->group(function () {
    route::get('/noticia/read/{id}', ['as' => 'site.noticia.read', 'uses' => 'Site\HomeController@noticiaRead']);
    route::get('/noticia', ['as' => 'site.noticia', 'uses' => 'Site\HomeController@noticia']);
    route::get('/historia', ['as' => 'site.historia', 'uses' => 'Site\HomeController@historia']);
});
Route::middleware(['auth'])->group(function () {
Route::prefix('/admin')->group(function () {

    route::get('/dashboard', ['as' => 'admin.dashboard', 'uses' => 'Site\HomeController@dash']);
    Route::get('/dashboard/index', ['as' => 'admin.escola.searchGet', 'uses' => 'Site\HomeController@dash']);


    Route::prefix('/municipio')->group(function () {

        route::get('/listar', [MunicipioController::class, 'listar'])
            ->name('admin.municipio.listar');

        route::post('/store', [MunicipioController::class, 'store'])
            ->name('admin.municipio.store');

        route::get('/editar/{id}', [MunicipioController::class, 'editar'])
            ->name('admin.municipio.editar');

        route::put('/update/{id}', [MunicipioController::class, 'update'])
            ->name('admin.municipio.update');

        route::get('/eliminar/{id}', [MunicipioController::class, 'eliminar'])
            ->name('admin.municipio.eliminar');
    });
    Route::prefix('/user')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.user.cadastrar', 'uses' => 'Admin\UserController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.user.editar', 'uses' => 'Admin\UserController@paginaEditar']);
        Route::post('/store', ['as' => 'admin.user.store', 'uses' => 'Admin\UserController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.user.listar', 'uses' => 'Admin\UserController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.user.eliminar', 'uses' => 'Admin\UserController@eliminar']);
        Route::post('/editar/{id}', ['as' => 'admin.user.update', 'uses' => 'Admin\UserController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.user.purgar', 'uses' => 'Admin\UserController@purgar']);
    });
    Route::prefix('/funcionario')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.funcionario.cadastrar', 'uses' => 'Admin\FuncionarioController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.funcionario.editar', 'uses' => 'Admin\FuncionarioController@paginaEditar']);
        Route::post('/store', ['as' => 'admin.funcionario.store', 'uses' => 'Admin\FuncionarioController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.funcionario.listar', 'uses' => 'Admin\FuncionarioController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.funcionario.eliminar', 'uses' => 'Admin\FuncionarioController@eliminar']);
        Route::post('/editar/{id}', ['as' => 'admin.funcionario.update', 'uses' => 'Admin\FuncionarioController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.funcionario.purgar', 'uses' => 'Admin\FuncionarioController@purgar']);
    });
    Route::prefix('/perfil')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.perfil.cadastrar', 'uses' => 'Admin\PerfilController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.perfil.editar', 'uses' => 'Admin\PerfilController@paginaEditar']);
        Route::post('/store', ['as' => 'admin.perfil.store', 'uses' => 'Admin\PerfilController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.perfil.listar', 'uses' => 'Admin\PerfilController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.perfil.eliminar', 'uses' => 'Admin\PerfilController@eliminar']);
        Route::post('/editar/{id}', ['as' => 'admin.perfil.update', 'uses' => 'Admin\PerfilController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.perfil.purgar', 'uses' => 'Admin\PerfilController@purgar']);
    });

    Route::prefix('/Sobre')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.sobre.cadastrar', 'uses' => 'Admin\SobreController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.sobre.editar', 'uses' => 'Admin\SobreController@paginaEditar']);
        Route::get('/detalhe/{id}', ['as' => 'admin.sobre.detalhe', 'uses' => 'Admin\SobreController@paginaDetalhe']);

        Route::post('/store', ['as' => 'admin.sobre.store', 'uses' => 'Admin\SobreController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.sobre.listar', 'uses' => 'Admin\SobreController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.sobre.eliminar', 'uses' => 'Admin\SobreController@eliminar']);
        Route::post('/editar/{id}', ['as' => 'admin.sobre.update', 'uses' => 'Admin\SobreController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.sobre.purgar', 'uses' => 'Admin\ProvinciaController@purgar']);
    });

    Route::prefix('/provincia')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.provincia.cadastrar', 'uses' => 'Admin\ProvinciaController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.provincia.editar', 'uses' => 'Admin\ProvinciaController@paginaEditar']);
        Route::post('/store', ['as' => 'admin.provincia.store', 'uses' => 'Admin\ProvinciaController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.provincia.listar', 'uses' => 'Admin\ProvinciaController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.provincia.eliminar', 'uses' => 'Admin\ProvinciaController@eliminar']);
        Route::post('/editar/{id}', ['as' => 'admin.provincia.update', 'uses' => 'Admin\ProvinciaController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.provincia.purgar', 'uses' => 'Admin\ProvinciaController@purgar']);
    });
    Route::prefix('/bairro')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.bairro.cadastrar', 'uses' => 'Admin\BairroController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.bairro.editar', 'uses' => 'Admin\BairroController@paginaEditar']);
        Route::post('/store', ['as' => 'admin.bairro.store', 'uses' => 'Admin\BairroController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.bairro.listar', 'uses' => 'Admin\BairroController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.bairro.eliminar', 'uses' => 'Admin\BairroController@eliminar']);
        Route::put('/editar/{id}', ['as' => 'admin.bairro.update', 'uses' => 'Admin\BairroController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.bairro.purgar', 'uses' => 'Admin\BairroController@purgar']);
    });
    Route::prefix('/departamento')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.departamento.cadastrar', 'uses' => 'Admin\DepartamentoController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.departamento.editar', 'uses' => 'Admin\DepartamentoController@paginaEditar']);
        Route::get('/detalhe/{id}', ['as' => 'admin.departamento.detalhe', 'uses' => 'Admin\DepartamentoController@paginaDetalhe']);

        Route::get('/listarFunc/{id}', ['as' => 'admin.departamento.funcionario', 'uses' => 'Admin\DepartamentoController@listarFuncionario']);

        Route::post('/store', ['as' => 'admin.departamento.store', 'uses' => 'Admin\DepartamentoController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.departamento.listar', 'uses' => 'Admin\DepartamentoController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.departamento.eliminar', 'uses' => 'Admin\DepartamentoController@eliminar']);
        Route::put('/editar/{id}', ['as' => 'admin.departamento.update', 'uses' => 'Admin\DepartamentoController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.departamento.purgar', 'uses' => 'Admin\DepartamentoController@purgar']);
    });
    Route::prefix('/departamentoFuncionario')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.departamentoFuncionario.cadastrar', 'uses' => 'Admin\DepartamentoFuncionarioController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.departamentoFuncionario.editar', 'uses' => 'Admin\DepartamentoFuncionarioController@paginaEditar']);
        Route::post('/store', ['as' => 'admin.departamentoFuncionario.store', 'uses' => 'Admin\DepartamentoFuncionarioController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.departamentoFuncionario.listar', 'uses' => 'Admin\DepartamentoFuncionarioController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.departamentoFuncionario.eliminar', 'uses' => 'Admin\DepartamentoFuncionarioController@eliminar']);
        Route::put('/editar/{id}', ['as' => 'admin.departamentoFuncionario.update', 'uses' => 'Admin\DepartamentoFuncionarioController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.departamentoFuncionario.purgar', 'uses' => 'Admin\DepartamentoFuncionarioController@purgar']);
        Route::get('/adicionarDep/{id}', ['as' => 'admin.departamentoFuncionario.adicionar', 'uses' => 'Admin\DepartamentoFuncionarioController@paginaAdicionarId']);
    });
    Route::prefix('/noticia')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.noticia.cadastrar', 'uses' => 'Admin\NoticiaController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.noticia.editar', 'uses' => 'Admin\NoticiaController@paginaEditar']);
        Route::post('/store', ['as' => 'admin.noticia.store', 'uses' => 'Admin\NoticiaController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.noticia.listar', 'uses' => 'Admin\NoticiaController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.noticia.eliminar', 'uses' => 'Admin\NoticiaController@eliminar']);
        Route::put('/editar/{id}', ['as' => 'admin.noticia.update', 'uses' => 'Admin\NoticiaController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.noticia.purgar', 'uses' => 'Admin\NoticiaController@purgar']);
        Route::get('/adicionarDep/{id}', ['as' => 'admin.noticia.adicionar', 'uses' => 'Admin\NoticiaController@paginaAdicionarId']);
    });
    Route::prefix('/categoria')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.categoria.cadastrar', 'uses' => 'Admin\CategoriaNoticiaController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.categoria.editar', 'uses' => 'Admin\CategoriaNoticiaController@paginaEditar']);
        Route::post('/store', ['as' => 'admin.categoria.store', 'uses' => 'Admin\CategoriaNoticiaController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.categoria.listar', 'uses' => 'Admin\CategoriaNoticiaController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.categoria.eliminar', 'uses' => 'Admin\CategoriaNoticiaController@eliminar']);
        Route::put('/editar/{id}', ['as' => 'admin.categoria.update', 'uses' => 'Admin\CategoriaNoticiaController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.categoria.purgar', 'uses' => 'Admin\CategoriaNoticiaController@purgar']);
    });
    Route::prefix('/documento')->group(function () {

        Route::get('/cadastrar', ['as' => 'admin.documento.cadastrar', 'uses' => 'Admin\DocumentoController@paginaCadastrar']);
        Route::get('/editar/{id}', ['as' => 'admin.documento.editar', 'uses' => 'Admin\DocumentoController@paginaEditar']);
        Route::post('/store', ['as' => 'admin.documento.store', 'uses' => 'Admin\DocumentoController@cadastrar']);
        Route::get('/listar', ['as' => 'admin.documento.listar', 'uses' => 'Admin\DocumentoController@listar']);
        Route::get('/eliminar/{id}', ['as' => 'admin.documento.eliminar', 'uses' => 'Admin\DocumentoController@eliminar']);
        Route::put('/editar/{id}', ['as' => 'admin.documento.update', 'uses' => 'Admin\DocumentoController@editar']);
        Route::get('/purgar/{id}', ['as' => 'admin.documento.purgar', 'uses' => 'Admin\DocumentoController@purgar']);
        Route::get('/adicionarDep/{id}', ['as' => 'admin.documento.adicionar', 'uses' => 'Admin\DocumentoController@paginaAdicionarId']);
    });
});
});
Route::get('admin/logs/pesquisar', ['as' => 'admin.logs.pesquisar.index', 'uses' => 'LogController@pesquisar']);
Route::post('admin/logs/recebelogs', ['as' => 'admin.logs.recebelogs', 'uses' => 'LogController@recebelogs']);
Route::get('admin/logs/visualizar/index/{datatime}/{utilizador}', ['as' => 'admin.logs.listar', 'uses' => 'LogController@index']);

require __DIR__ . '/auth.php';
